"""
Django settings for src project.

Generated by 'django-admin startproject' using Django 1.8.4.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
import random

from django.utils.translation import gettext_lazy as _
import logging

# from azbankintro import BankEnum

BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ.get('DJANGO_SECRET_KEY')
if not SECRET_KEY:
    raise ValueError('Secret key does not set')

INSTALLED_APPS = [
    # built in
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.humanize',
    'django.contrib.sitemaps',
    # third party apps
    # my apps
    'azbankgateways',
    'examples',
]

MIDDLEWARE = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.common.CommonMiddleware',
    # third party
]

ROOT_URLCONF = 'DJANGO_PROJECT.urls.common_urls'
ASGI_APPLICATION = "DJANGO_PROJECT.routing.application"

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'debug': True,
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql',
        'NAME': os.environ.get('DATABASE_NAME'),
        'USER': os.environ.get('DATABASE_USER'),
        'PASSWORD': os.environ.get('DATABASE_PASSWORD'),
        'HOST': os.environ.get('DATABASE_HOST'),
        'PORT': os.environ.get('DATABASE_PORT', ''),
        "OPTIONS": {
            "client_encoding": 'UTF8',
        },
    },
}

# Internationalization

# Allow all host headers
ALLOWED_HOSTS = ['*']

CORS_ORIGIN_ALLOW_ALL = True

FILE_ACCESS_PATH = os.path.join(os.path.dirname(BASE_DIR), 'file_access')

# STATICFILES_DIRS = (
#     os.path.join(BASE_DIR, 'static'),
# )

MEDIA_ROOT = os.path.join(FILE_ACCESS_PATH, "media")
MEDIA_URL = "%s/%s/" % ('', 'media')
LANGUAGE_CODE = 'en-us'  # 'en-us'

TIME_ZONE = 'Asia/Tehran'

USE_I18N = True

USE_L10N = True

LOCALE_PATHS = (
    os.path.join(BASE_DIR, 'locale/'),
)

LANGUAGES = [
    ('fa', _('Persian')),
    ('en', _('English')),
    # ('es', _('Espaniol')),
]


STATIC_ROOT = os.path.join(FILE_ACCESS_PATH, 'staticfiles')
STATIC_URL = "%s/%s/" % ('', 'staticfiles')

AZ_IRANIAN_BANK_GATEWAYS = {
    'CLASS': {
        'BMI': 'azbankgateways.banks.BMI',
        'SEP': 'azbankgateways.banks.SEP',
        'ZARINPAL': 'azbankgateways.banks.Zarinpal',
        'IDPAY': 'azbankgateways.banks.IDPay',
        'ZIBAL': 'azbankgateways.banks.Zibal',
        'BAHAMTA': 'azbankgateways.banks.Bahamta',
    },
    'GATEWAYS': {
        'BMI': {
            'MERCHANT_CODE': '000000140333294',
            'TERMINAL_CODE': '24088323',
            'SECRET_KEY': 'oi+dBkKk66TZx60jKibSaIiMAhvyX3O6',
        },
        'SEP': {
            'MERCHANT_CODE': '11761697',
            'TERMINAL_CODE': '9837072',
        },
        'ZARINPAL': {
            'MERCHANT_CODE': '8ba4d26a-1880-11e9-bfa1-005056a205be',
        },
        'IDPAY': {
            'MERCHANT_CODE': 'e2499aa5-9080-4ae7-8fca-4663c4622744',
            'METHOD': 'POST',  # GET or POST
            'X_SANDBOX': 1,  # 0 disable, 1 active
        },
        'ZIBAL': {
            'MERCHANT_CODE': '5fd1f90f18f934489dcb0e4a',
        },
        'BAHAMTA': {
            'MERCHANT_CODE': 'webpay:05f4565d-5608-4ef4-ab8c-64568c9b7337:6740e08f-5f28-4012-a285-16807d6b30d5',
        },
        'IKC': {
            'MERCHANT_CODE': '992180008082470',
            'SHA_1_KEY': '08082470',
        },  # بانک تجارت
        'MELLAT': {
            'TERMINAL_CODE': '5974608',
            'USERNAME': 'array group777',
            'PASSWORD': '59080044',
        },
    },
    'IS_SAMPLE_FORM_ENABLE': True,
    'DEFAULT': 'ZIBAL',
    'CURRENCY': 'IRR',
    'TRACKING_CODE_QUERY_PARAM': 'tc',
    'TRACKING_CODE_LENGTH': 16,
    'SETTING_VALUE_READER_CLASS': 'azbankgateways.readers.DefaultReader',
    'BANK_PRIORITIES': [
        'ZIBAL',
        # 'IKC',
        # 'BMI',
        # 'IDPAY',
        # 'MELLAT',
        # 'SEP',
        # 'ZARINPAL',
        # ...
    ],
}

DEBUG = True
